@@ -16,16 +16,17 @@ from .__about__ import __version__
 __all__ = all_mesh + all_assembly + all_element + [  # noqa
     'MappingAffine',
     'MappingIsoparametric',
-    'MappingMortar',
+    'MappingMortar',  # TODO remove due to deprecation
     'adaptive_theta',
     'build_pc_ilu',
     'build_pc_diag',
     'condense',
     'enforce',
     'penalize',
-    'project',
-    'projection',
+    'project',  # TODO remove due to deprecation
+    'projection',  # TODO remove due to deprecation
     'solve',
+    'bmat',
     'solver_direct_scipy',
     'solver_eigen_scipy',
     'solver_eigen_scipy_sym',
