@@ -80,9 +80,7 @@ def asm(form: Form,
     assert form.form is not None
     logger.info("Assembling '{}'.".format(form.form.__name__))
     nargs = [[arg] if not isinstance(arg, list) else arg for arg in args]
-    retval = to(map(lambda a: form.coo_data(*a[1],
-                                            idx=a[0],
-                                            **kwargs),
+    retval = to(map(lambda a: form.coo_data(*a[1], idx=a[0], **kwargs),
                     zip(product(*(range(len(x)) for x in nargs)),
                         product(*nargs))))
     logger.info("Assembling finished.")
