@@ -1,18 +1,17 @@
 import logging
 import importlib
 from warnings import warn
-from typing import Any, Dict, List, Optional, Tuple, Type, Union
+from typing import Any, List, Optional, Tuple, Type, Union
 
 import numpy as np
 from numpy import ndarray
-from skfem.assembly.dofs import Dofs, DofsView
+from skfem.assembly.dofs import Dofs
 from skfem.element import (DiscreteField, Element, ElementComposite,
                            ElementVector)
 from skfem.mapping import Mapping
 from skfem.mesh import Mesh
 from skfem.quadrature import get_quadrature
 from skfem.refdom import Refdom
-from skfem.generic_utils import deprecated
 
 
 logger = logging.getLogger(__name__)
@@ -119,23 +118,10 @@ class AbstractBasis:
             D = tuple(D[0][key].all() for key in D[0])
         return np.setdiff1d(np.arange(self.N), np.concatenate(D))
 
-    @deprecated("Basis.get_dofs")
-    def find_dofs(self,
-                  facets: Dict[str, ndarray] = None,
-                  skip: List[str] = None) -> Dict[str, DofsView]:
-        if facets is None:
-            if self.mesh.boundaries is None:
-                facets = {'all': self.mesh.boundary_facets()}
-            else:
-                facets = self.mesh.boundaries
-
-        return {k: self.dofs.get_facet_dofs(facets[k], skip_dofnames=skip)
-                for k in facets}
-
     def get_dofs(self,
                  facets: Optional[Any] = None,
                  elements: Optional[Any] = None,
-                 skip: List[str] = None) -> Any:
+                 skip: Optional[List[str]] = None) -> Any:
         """Find global DOF numbers.
 
         Accepts an array of facet/element indices.  However, various argument
@@ -295,13 +281,13 @@ class AbstractBasis:
 
         # loop over solution components
         for c in range(len(refs)):
-            ref = refs[c][1].basis[0][0]
-            ref = ref.astuple
-            fs = []
+            ref = refs[c][1].basis[0][0].astuple
 
-            def linear_combination(n, refn):
+            def linear_combination(n):
                 """Global discrete function at quadrature points."""
-                out = 0. * refn.copy()
+                out = 0. * np.einsum('...,...j->...j',
+                                     w[self.element_dofs[0]],
+                                     self.basis[0][c].get(n))
                 for i in range(self.Nbfun):
                     values = w[self.element_dofs[i]]
                     out += np.einsum('...,...j->...j', values,
@@ -309,9 +295,10 @@ class AbstractBasis:
                 return out
 
             # interpolate DiscreteField
+            fs = []
             for n in range(len(ref)):
                 if ref[n] is not None:
-                    fs.append(linear_combination(n, ref[n]))
+                    fs.append(linear_combination(n))
                 else:
                     fs.append(None)
 
@@ -323,17 +310,12 @@ class AbstractBasis:
 
     def split_indices(self) -> List[ndarray]:
         """Return indices for the solution components."""
-        if ((isinstance(self.elem, ElementComposite)
-             or isinstance(self.elem, ElementVector))):
-            nelems = (len(self.elem.elems)
-                      if isinstance(self.elem, ElementComposite)
-                      else self.mesh.dim())
+        output: List[ndarray] = []
+        if isinstance(self.elem, ElementComposite):
+            nelems = len(self.elem.elems)
             o = np.zeros(4, dtype=np.int64)
-            output: List[ndarray] = []
             for k in range(nelems):
-                e = (self.elem.elems[k]
-                     if isinstance(self.elem, ElementComposite)
-                     else self.elem.elem)
+                e = self.elem.elems[k]
                 output.append(np.concatenate((
                     self.nodal_dofs[o[0]:(o[0] + e.nodal_dofs)].flatten('F'),
                     self.edge_dofs[o[1]:(o[1] + e.edge_dofs)].flatten('F'),
@@ -346,6 +328,17 @@ class AbstractBasis:
                                e.facet_dofs,
                                e.interior_dofs])
             return output
+        elif isinstance(self.elem, ElementVector):
+            ndims = self.mesh.dim()
+            e = self.elem.elem
+            for k in range(ndims):
+                output.append(np.concatenate((
+                    self.nodal_dofs[k::ndims].flatten('F'),
+                    self.edge_dofs[k::ndims].flatten('F'),
+                    self.facet_dofs[k::ndims].flatten('F'),
+                    self.interior_dofs[k::ndims].flatten('F'),
+                )).astype(np.int64))
+            return output
         return [np.unique(self.dofs.element_dofs)]
 
     def split_bases(self) -> List['AbstractBasis']:
@@ -369,14 +362,19 @@ class AbstractBasis:
         xs = [x[ix] for ix in self.split_indices()]
         return list(zip(xs, self.split_bases()))
 
-    def zero_w(self) -> ndarray:
+    def zero_w(self, dtype=None) -> ndarray:
         """Return a zero array with correct dimensions for
         :func:`~skfem.assembly.asm`."""
-        return np.zeros((self.nelems, 0 if self.W is None else len(self.W)))
+        return np.zeros((self.nelems, 0 if self.W is None else len(self.W)),
+                        dtype=dtype)
 
-    def zeros(self) -> ndarray:
+    def zeros(self, dtype=None) -> ndarray:
         """Return a zero array with same dimensions as the solution."""
-        return np.zeros(self.N)
+        return np.zeros(self.N, dtype=dtype)
+
+    def ones(self, dtype=None) -> ndarray:
+        """Return a ones array with same dimensions as the solution."""
+        return np.ones(self.N, dtype=dtype)
 
     def with_element(self, elem: Element) -> 'AbstractBasis':
         """Create a copy of ``self`` that uses different element."""
@@ -387,33 +385,37 @@ class AbstractBasis:
 
     def _normalize_interp(self, interp) -> Tuple[ndarray, ...]:
 
-        if isinstance(interp, ndarray):
-            pass
-        elif callable(interp):
-            interp = interp(self.global_coordinates())
-        elif isinstance(interp, (float, int)):
+        if isinstance(interp, (tuple, list)):
+            interp = tuple(self._normalize_interp(c)[0] for c in interp)
+
+        if callable(interp):
+            interp = self._normalize_interp(interp(self.global_coordinates()))
+
+        if isinstance(interp, (float, int)):
             interp = interp + self.zero_w()
-        elif isinstance(interp, (tuple, list)):
-            interp = tuple(self._normalize_interp(c) for c in interp)
+
+        if isinstance(interp, ndarray):
+            interp = (interp,)
 
         return interp
 
-    def _projection(self, interp):
+    def _projection(self, interp, dtype=None):
 
         from skfem.assembly import BilinearForm, LinearForm
         from skfem.helpers import inner
 
         interp = self._normalize_interp(interp)
-        if not isinstance(interp, tuple):
-            interp = (interp,)
+        assert isinstance(interp, tuple)
         assert len(interp) == len(self.basis[0])
 
         return (
             (BilinearForm(lambda *args: inner(args[:(len(args) - 1) // 2],
-                                              args[(len(args) - 1) // 2:-1]))
+                                              args[(len(args) - 1) // 2:-1]),
+                          dtype=dtype)
              .assemble(self)),
             (LinearForm(lambda *args: inner(interp,
-                                            args[:(len(args) - 1)]))
+                                            args[:(len(args) - 1)]),
+                        dtype=dtype)
              .assemble(self)),
         )
 
