@@ -96,7 +96,7 @@ class CellBasis(AbstractBasis):
                       for j in range(self.Nbfun)]
 
         self.dx = (np.abs(self.mapping.detDF(self.X, tind=self.tind))
-                   * np.tile(self.W, (self.nelems, 1)))
+                   * np.broadcast_to(self.W, (self.nelems, self.W.shape[-1])))
         logger.info("Initializing finished.")
 
     def default_parameters(self):
@@ -121,7 +121,13 @@ class CellBasis(AbstractBasis):
         # mesh reference domain, refine and take the vertices
         meshclass = type(self.mesh)
         m = meshclass.init_refdom().refined(nrefs)
-        X = m.p
+
+        if self.mesh.dim() == 1:
+            # this workaround makes sorting preserve correct order of duplicate
+            # nodes in skfem.visuals.matplotlib.plot_meshline
+            X = (1. - 1e-10) * m.p + 5e-11
+        else:
+            X = m.p
 
         # map vertices to global elements
         x = self.mapping.F(X)
@@ -130,9 +136,9 @@ class CellBasis(AbstractBasis):
         # of the refined mesh
         test = self.elem.gbasis(self.mapping, X, 0)[0]
         if len(test.shape) == 3:
-            w = 0. * x
+            w = np.zeros_like(x, dtype=y.dtype)
         elif len(test.shape) == 2:
-            w = 0. * x[0]
+            w = np.zeros_like(x[0], dtype=y.dtype)
         else:
             raise NotImplementedError
         for j in range(self.Nbfun):
@@ -231,13 +237,20 @@ class CellBasis(AbstractBasis):
             elements=self.tind,
         )
 
-    def boundary(self, facets: Optional[Any] = None):
+    def boundary(self,
+                 facets: Optional[Any] = None,
+                 intorder: Optional[int] = None,
+                 quadrature: Optional[Tuple[ndarray, ndarray]] = None):
         """Return corresponding :class:`~skfem.assembly.basis.FacetBasis`.
 
         Parameters
         ----------
         facets
             Anything that can be passed to ``FacetBasis(..., facets=facets)``.
+        intorder
+            Optionally, specify integration order.
+        quadrature
+            Optionally, specify quadrature.
 
         """
         from skfem.assembly.basis.facet_basis import FacetBasis
@@ -248,9 +261,11 @@ class CellBasis(AbstractBasis):
             self.elem,
             mapping=self.mapping,
             facets=facets,
+            intorder=intorder,
+            quadrature=quadrature,
         )
 
-    def project(self, interp, elements=None):
+    def project(self, interp, elements=None, dtype=None):
         """Perform :math:`L^2` projection onto the basis.
 
         See :ref:`l2proj` for more information.
@@ -270,7 +285,7 @@ class CellBasis(AbstractBasis):
         """
         from skfem.utils import solve, condense
 
-        M, f = self._projection(interp)
+        M, f = self._projection(interp, dtype=dtype)
 
         if elements is not None:
             return solve(*condense(M, f, I=self.get_dofs(elements=elements)))
