@@ -1,4 +1,4 @@
-from dataclasses import dataclass, replace
+from dataclasses import dataclass, replace, field
 from typing import Union, Any, List, Optional
 
 import numpy as np
@@ -14,14 +14,21 @@ class DofsView:
     """A subset of :class:`skfem.assembly.Dofs`."""
 
     obj: Any = None
-    nodal_ix: Union[ndarray, slice] = slice(None)
-    facet_ix: Union[ndarray, slice] = slice(None)
-    edge_ix: Union[ndarray, slice] = slice(None)
-    interior_ix: Union[ndarray, slice] = slice(None)
-    nodal_rows: Union[ndarray, slice] = slice(None)
-    facet_rows: Union[ndarray, slice] = slice(None)
-    edge_rows: Union[ndarray, slice] = slice(None)
-    interior_rows: Union[ndarray, slice] = slice(None)
+    nodal_ix: Union[ndarray, slice] = field(
+        default_factory=lambda: slice(None))
+    facet_ix: Union[ndarray, slice] = field(
+        default_factory=lambda: slice(None))
+    edge_ix: Union[ndarray, slice] = field(default_factory=lambda: slice(None))
+    interior_ix: Union[ndarray, slice] = field(
+        default_factory=lambda: slice(None))
+    nodal_rows: Union[ndarray, slice] = field(
+        default_factory=lambda: slice(None))
+    facet_rows: Union[ndarray, slice] = field(
+        default_factory=lambda: slice(None))
+    edge_rows: Union[ndarray, slice] = field(
+        default_factory=lambda: slice(None))
+    interior_rows: Union[ndarray, slice] = field(
+        default_factory=lambda: slice(None))
 
     def __repr__(self):
         nnodal = len(np.unique(
@@ -297,9 +304,10 @@ class Dofs:
         # total dofs
         self.N = np.max(self.element_dofs) + 1
 
-    def get_element_dofs(self,
-                         elements: ndarray,
-                         skip_dofnames: List[str] = None) -> DofsView:
+    def get_element_dofs(
+            self,
+            elements: ndarray,
+            skip_dofnames: Optional[List[str]] = None) -> DofsView:
         """Return a subset of DOFs corresponding to the given elements.
 
         Parameters
@@ -335,7 +343,7 @@ class Dofs:
 
     def get_facet_dofs(self,
                        facets: ndarray,
-                       skip_dofnames: List[str] = None) -> DofsView:
+                       skip_dofnames: Optional[List[str]] = None) -> DofsView:
         """Return a subset of DOFs corresponding to the given facets.
 
         Parameters
