@@ -38,6 +38,10 @@ class COOData:
     def __radd__(self, other):
         return self.__add__(other)
 
+    def __array__(self):
+        # allow passing a list of COOData objects to, e.g., np.concatenate
+        return self.toarray()
+
     def tolocal(self, basis=None):
         """Return an array of local finite element matrices.
 
