@@ -42,8 +42,19 @@ def curl(u: DiscreteField):
     if u.curl is not None:
         return u.curl
     elif u.grad is not None:
-        if u.grad.shape[0] == 2:
+        if len(u.grad.shape) == 3 and u.grad.shape[0] == 2:
+            # curl of scalar field
             return np.array([u.grad[1], -u.grad[0]])
+        elif len(u.grad.shape) == 4 and u.grad.shape[0] == 2:
+            # 2d-curl of vector field
+            return u.grad[1, 0] - u.grad[0, 1]
+        elif len(u.grad.shape) == 4 and u.grad.shape[0] == 3:
+            # full 3d curl
+            return np.array([
+                u.grad[2, 1] - u.grad[1, 2],
+                u.grad[0, 2] - u.grad[2, 0],
+                u.grad[1, 0] - u.grad[0, 1],
+            ])
     raise NotImplementedError
 
 
@@ -195,3 +206,14 @@ def inv(A):
         invA[1, 0] = -A[1, 0] / detA
         invA[1, 1] = A[0, 0] / detA
     return invA
+
+
+def cross(A, B):
+    if A.shape[0] == 2:
+        return A[0] * B[1] - A[1] * B[0]
+    if A.shape[0] == 3:
+        return np.array([
+            A[1] * B[2] - A[2] * B[1],
+            A[2] * B[0] - A[0] * B[2],
+            A[0] * B[1] - A[1] * B[0]
+        ])
