@@ -4,6 +4,7 @@ from typing import Optional
 import numpy as np
 from numpy import ndarray
 
+from ..generic_utils import deprecated
 from ..mesh import Mesh2D
 from .mapping import Mapping
 
@@ -13,6 +14,7 @@ class MappingMortar(Mapping):
 
     side = 0
 
+    @deprecated("skfem.supermeshing")
     def __init__(self,
                  maps,
                  helper_to_orig,
@@ -176,7 +178,7 @@ class MappingMortar(Mapping):
 
     def G(self,
           X: ndarray,
-          find: ndarray = None,
+          find: Optional[ndarray] = None,
           side: Optional[int] = None) -> ndarray:
         side = self.side if side is None else side
         return self.maps[side].G(
@@ -187,7 +189,7 @@ class MappingMortar(Mapping):
 
     def detDG(self,
               X: ndarray,
-              find: ndarray = None) -> ndarray:
+              find: Optional[ndarray] = None) -> ndarray:
         if X.shape[0] == 1:
             segs = self.G(np.array([[0., 1.]]), side=0)
             return np.sqrt(np.diff(segs[0], axis=1) ** 2 +
