@@ -418,7 +418,6 @@ class Mesh:
         return vertices, edges
 
     def _mapping(self):
-        """Return a default reference mapping for the mesh."""
         from skfem.mapping import MappingAffine, MappingIsoparametric
         if not hasattr(self, '_cached_mapping'):
             if self.affine:
@@ -431,6 +430,10 @@ class Mesh:
                 )
         return self._cached_mapping
 
+    def mapping(self):
+        """Return a default reference mapping for the mesh."""
+        return self._mapping()
+
     def _init_facets(self):
         """Initialize ``self.facets``."""
         self._facets, self._t2f = self.build_entities(
@@ -464,8 +467,9 @@ class Mesh:
 
         M = self.elem.refdom.nnodes
 
-        if self.nnodes > M:
+        if self.nnodes > M and self.elem is not Element:
             # reorder DOFs to the expected format: vertex DOFs are first
+            # note: not run if elem is not set
             p, t = self.doflocs, self.t
             t_nodes = t[:M]
             uniq, ix = np.unique(t_nodes, return_inverse=True)
@@ -492,10 +496,11 @@ class Mesh:
                                "to C_CONTIGUOUS.")
             self.t = np.ascontiguousarray(self.t)
 
-        # add boundary tags for the default cubes
+        # try adding default boundary tags
         if ((self._boundaries is None
-             and self.doflocs.shape[1] == 2 ** self.dim()
-             and self.dim() <= 2)):
+             and self.doflocs.shape[1] < 1e3
+             and self.elem is not Element)):
+            # note: not run if elem is not set
             boundaries = {}
             # default boundary names along the dimensions
             minnames = ['left', 'bottom', 'front']
@@ -567,6 +572,9 @@ class Mesh:
         logger.debug("Mesh validation completed with no warnings.")
         return True
 
+    def __iter__(self):
+        return iter((self.doflocs, self.t))
+
     def __rmatmul__(self, other):
         out = self.__matmul__(other)
         return out[1:] + out[0:1]
@@ -953,12 +961,60 @@ class Mesh:
         """Return mesh parameter, viz the length of the longest edge."""
         raise NotImplementedError
 
-    def _reix(self, ix: ndarray) -> Tuple[ndarray, ndarray]:
+    def _reix(self, ix: ndarray) -> Tuple[ndarray, ndarray, ndarray]:
         """Connect ``self.p`` based on the indices ``ix``."""
         ixuniq = np.unique(ix)
         t = np.zeros(np.max(ix) + 1, dtype=np.int64)
         t[ixuniq] = np.arange(len(ixuniq), dtype=np.int64)
-        return self.p[:, ixuniq], t[ix]
+        return (
+            np.ascontiguousarray(self.p[:, ixuniq]),
+            np.ascontiguousarray(t[ix]),
+            ixuniq
+        )
+
+    def trace(self, facets, mtype=None, project=None):
+        """Create a trace mesh.
+
+        Parameters
+        ----------
+        facets
+            Criteria of which facets to include.  This input is normalized
+            using ``self.normalize_facets``.
+        mtype
+            Optional subtype of Mesh which is used to initialize the return
+            value.  If not provided, the raw Mesh type is used.
+        project
+            Optional lambda for modifying doflocs before initializing.  Usually
+            for projecting doflocs because trace may lead to a lower
+            dimensional mesh.  Useful example is ``lambda p: p[1:]``.
+
+        """
+        facets = self.normalize_facets(facets)
+        p, t, _ = self._reix(self.facets[:, facets])
+        return (Mesh if mtype is None else mtype)(
+            (project(p) if project is not None else p),
+            t
+        ), facets
+
+    def restrict(self, elements):
+        """Restrict the mesh to a subset of elements.
+
+        Parameters
+        ----------
+        elements
+            Criteria of which elements to include.  This input is normalized
+            using ``self.normalize_elements``.
+
+        """
+        elements = self.normalize_elements(elements)
+        p, t, _ = self._reix(self.t[:, elements])
+        return replace(
+            self,
+            doflocs=p,
+            t=t,
+            _boundaries=None,
+            _subdomains=None,
+        )
 
     def remove_elements(self, element_indices: ndarray):
         """Construct a new mesh by removing elements.
@@ -969,11 +1025,13 @@ class Mesh:
             List of element indices to remove.
 
         """
-        p, t = self._reix(np.delete(self.t, element_indices, axis=1))
+        p, t, _ = self._reix(np.delete(self.t, element_indices, axis=1))
         return replace(
             self,
             doflocs=p,
             t=t,
+            _boundaries=None,
+            _subdomains=None,
         )
 
     def element_finder(self, mapping=None):
