@@ -1,4 +1,4 @@
-from dataclasses import dataclass, replace
+from dataclasses import dataclass, replace, field
 from typing import Type
 
 import numpy as np
@@ -13,12 +13,16 @@ from .mesh_simplex import MeshSimplex
 class MeshTri1(MeshSimplex, Mesh2D):
     """A standard first-order triangular mesh."""
 
-    doflocs: ndarray = np.array([[0., 0.],
-                                 [1., 0.],
-                                 [0., 1.],
-                                 [1., 1.]], dtype=np.float64).T
-    t: ndarray = np.array([[0, 1, 2],
-                           [1, 3, 2]], dtype=np.int64).T
+    doflocs: ndarray = field(
+        default_factory=lambda: np.array(
+            [[0.0, 0.0], [1.0, 0.0], [0.0, 1.0], [1.0, 1.0]], dtype=np.float64
+        ).T
+    )
+    t: ndarray = field(
+        default_factory=lambda: np.array(
+            [[0, 1, 2], [1, 3, 2]], dtype=np.int64
+        ).T
+    )
     elem: Type[Element] = ElementTriP1
     affine: bool = True
     sort_t: bool = True
