@@ -1,4 +1,4 @@
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from typing import Type
 
 import numpy as np
@@ -12,12 +12,20 @@ from .mesh_dg import MeshDG
 @dataclass(repr=False)
 class MeshTri1DG(MeshDG, MeshTri1):
     """A triangular mesh with a discontinuous topology."""
-    doflocs: ndarray = np.array([[0., 0.],
-                                 [1., 0.],
-                                 [0., 1.],
-                                 [1., 0.],
-                                 [0., 1.],
-                                 [1., 1.]], dtype=np.float64).T
+
+    doflocs: ndarray = field(
+        default_factory=lambda: np.array(
+            [
+                [0.0, 0.0],
+                [1.0, 0.0],
+                [0.0, 1.0],
+                [1.0, 0.0],
+                [0.0, 1.0],
+                [1.0, 1.0],
+            ],
+            dtype=np.float64,
+        ).T
+    )
     elem: Type[Element] = ElementTriP1DG
     affine: bool = False
     sort_t: bool = False
