@@ -311,7 +311,7 @@ def _init_bc(A: spmatrix,
     assert isinstance(D, ndarray)
 
     if x is None:
-        x = np.zeros(A.shape[0])
+        x = np.zeros(A.shape[0], dtype=A.dtype)
     elif b is None:
         b = np.zeros_like(x)
 
@@ -600,6 +600,36 @@ def condense(A: spmatrix,
 # additional utilities
 
 
+def bmat(blocks, *args, **kwargs):
+    """A variant of scipy bmat which adds block indices to out.blocks."""
+    m = len(blocks)
+    n = len(blocks[0])
+
+    # turn COOData into scipy/numpy
+    blocks = [[coo.todefault() if hasattr(coo, 'todefault') else coo
+               for coo in row] for row in blocks]
+
+    sizes = []
+    diff = 0
+
+    for j in range(n - 1):
+        for i in range(m):
+            if blocks[i][j] is None:
+                continue
+            else:
+                if len(blocks[i][j].shape) == 1:
+                    sizes.append(blocks[i][j].shape[0] + diff)
+                else:
+                    sizes.append(blocks[i][j].shape[1] + diff)
+                diff += sizes[-1]
+                break
+
+    mat = sp.bmat(blocks, *args, **kwargs)
+    mat.blocks = sizes  # add block sizes as an attribute
+
+    return mat
+
+
 def rcm(A: spmatrix,
         b: ndarray) -> Tuple[spmatrix, ndarray, ndarray]:
     """Reverse Cuthill-McKee ordering."""
