@@ -32,10 +32,13 @@ def draw_basis(ib: CellBasis, **kwargs) -> Axes:
 
 
 @draw.register(Mesh3D)
-def draw_meshhex(m: Mesh3D, **kwargs) -> Axes:
+def draw_mesh3d(m: Mesh3D, **kwargs) -> Axes:
     """Visualize a three-dimensional mesh by drawing the edges."""
-    ax = plt.figure().add_subplot(1, 1, 1, projection='3d')
-    for ix in range(m.edges.shape[1]):
+    if 'ax' not in kwargs:
+        ax = plt.figure().add_subplot(1, 1, 1, projection='3d')
+    else:
+        ax = kwargs['ax']
+    for ix in m.boundary_edges():
         ax.plot3D(
             m.p[0, m.edges[:, ix]].flatten(),
             m.p[1, m.edges[:, ix]].flatten(),
@@ -90,6 +93,7 @@ def draw_mesh2d(m: Mesh2D, **kwargs) -> Axes:
         facets = m.facets[:, m.boundary_facets()]
     else:
         facets = m.facets
+    plot_kwargs = kwargs["plot_kwargs"] if "plot_kwargs" in kwargs else {}
     # faster plotting is achieved through
     # None insertion trick.
     xs = []
@@ -107,7 +111,8 @@ def draw_mesh2d(m: Mesh2D, **kwargs) -> Axes:
     ax.plot(xs,
             ys,
             kwargs['color'] if 'color' in kwargs else 'k',
-            linewidth=kwargs['linewidth'] if 'linewidth' in kwargs else .5)
+            linewidth=kwargs['linewidth'] if 'linewidth' in kwargs else .5,
+            **plot_kwargs)
 
     if "boundaries" in kwargs:
         cm = plt.get_cmap('gist_rainbow')
@@ -130,7 +135,8 @@ def draw_mesh2d(m: Mesh2D, **kwargs) -> Axes:
                     ys,
                     color=colors[i % len(colors)],
                     linewidth=(kwargs['linewidth']
-                               if 'linewidth' in kwargs else 2.))
+                               if 'linewidth' in kwargs else 2.),
+                    **plot_kwargs)
             if hasattr(m.boundaries[k], 'ori'):
                 tris = m.f2t[m.boundaries[k].ori, m.boundaries[k]]
                 color = colors[i % len(colors)][:3] + (.1,)
@@ -160,6 +166,27 @@ def draw_mesh2d(m: Mesh2D, **kwargs) -> Axes:
     return ax
 
 
+@draw.register(MeshLine1)
+def draw_meshline(m: MeshLine1, **kwargs):
+    """Draw the nodes of one-dimensional mesh."""
+    if "ax" not in kwargs:
+        # create new figure
+        fig = plt.figure()
+        ax = fig.add_subplot(111)
+    else:
+        ax = kwargs["ax"]
+
+    color = kwargs["color"] if "color" in kwargs else 'ko-'
+    ix = np.argsort(m.p[0])
+
+    plot_kwargs = kwargs["plot_kwargs"] if "plot_kwargs" in kwargs else {}
+
+    ax.plot(m.p[0][ix], 0. * m.p[0][ix], color, **plot_kwargs)
+
+    ax.show = lambda: plt.show()
+    return ax
+
+
 @singledispatch
 def plot(m, u, **kwargs) -> Axes:
     """Plot functions defined on nodes of the mesh."""
@@ -177,9 +204,9 @@ def plot_meshline(m: MeshLine1, z: ndarray, **kwargs):
         ax = kwargs["ax"]
 
     color = kwargs["color"] if "color" in kwargs else 'ko-'
+    plot_kwargs = kwargs["plot_kwargs"] if "plot_kwargs" in kwargs else {}
     ix = np.argsort(m.p[0])
-    ax.plot(m.p[0][ix], z[ix], color)
-
+    ax.plot(m.p[0][ix], z[ix], color, **plot_kwargs)
     ax.show = lambda: plt.show()
     return ax
 
@@ -230,6 +257,8 @@ def plot_meshtri(m: MeshTri1, z: ndarray, **kwargs) -> Axes:
     else:
         cmap = plt.cm.jet
 
+    plot_kwargs = kwargs["plot_kwargs"] if "plot_kwargs" in kwargs else {}
+
     if len(z) == 2 * len(m.p[0]):
         im = ax.quiver(m.p[0], m.p[1], *z.reshape(2, -1),
                        **{k: v for k, v in kwargs.items()
@@ -240,26 +269,29 @@ def plot_meshtri(m: MeshTri1, z: ndarray, **kwargs) -> Axes:
                                    'headlength',
                                    'minshaft',
                                    'pivot',
-                                   'color']})
+                                   'color']},  # for backwards compatibility
+                       **plot_kwargs)
     else:
         im = ax.tripcolor(m.p[0], m.p[1], m.t.T, z, cmap=cmap,
                           **{k: v for k, v in kwargs.items()
                              if k in ['shading',
                                       'edgecolors',
                                       'vmin',
-                                      'vmax']})
+                                      'vmax']},  # for backwards compatibility
+                          **plot_kwargs)
 
     if "levels" in kwargs:
         ax.tricontour(m.p[0], m.p[1], m.t.T, z,
-                      levels=kwargs["levels"], colors='k')
+                      levels=kwargs["levels"],
+                      **{**{'colors': 'k'}, **plot_kwargs})
 
     if "colorbar" in kwargs:
         if isinstance(kwargs["colorbar"], str):
-            plt.colorbar(im, label=kwargs["colorbar"])
+            plt.colorbar(im, ax=ax, label=kwargs["colorbar"])
         elif isinstance(kwargs["colorbar"], dict):
-            plt.colorbar(im, **kwargs["colorbar"])
+            plt.colorbar(im, ax=ax, **kwargs["colorbar"])
         else:
-            plt.colorbar(im)
+            plt.colorbar(im, ax=ax)
 
     ax.show = lambda: plt.show()
     return ax
